@@ -1,9 +1,12 @@
 import numpy
+import pandas
 from scipy import optimize, sparse, spatial, stats
 
 from ._utils import (
     _build_coincidence_lookup,
+    _induce_cliques,
     _jitter_geoms,
+    _reorder_adjtable_by_ids,
     _resolve_islands,
     _sparse_to_arrays,
     _validate_geometry_input,
@@ -212,7 +215,7 @@ def _knn(coordinates, metric="euclidean", k=1, p=2, coincident="raise"):
     max_at_one_site = coincident_lut.input_index.str.len().max()
     n_samples, _ = coordinates.shape
 
-    if max_at_one_site <= k:
+    if n_coincident == 0:
         if metric == "haversine":
             # sklearn haversine works with (lat,lng) in radians...
             coordinates = numpy.fliplr(numpy.deg2rad(coordinates))
@@ -230,7 +233,6 @@ def _knn(coordinates, metric="euclidean", k=1, p=2, coincident="raise"):
             shape=(n_samples, n_samples),
         )
         return d
-
     else:
         if coincident == "raise":
             raise ValueError(
@@ -253,28 +255,25 @@ def _knn(coordinates, metric="euclidean", k=1, p=2, coincident="raise"):
             )
 
         if coincident == "clique":
-            raise NotImplementedError(
-                "clique-based resolver of coincident points is not yet implemented."
+            heads, tails, weights = _sparse_to_arrays(
+                _knn(
+                    coincident_lut.geometry, metric=metric, k=k, p=p, coincident="raise"
+                )
             )
-            # # implicit coincident == "clique"
-            # heads, tails, weights = _sparse_to_arrays(
-            #     _knn(
-            #         coincident_lut.geometry,
-            #         metric=metric,
-            #         k=k,
-            #         p=p,
-            #         coincident="raise"
-            #     )
-            # )
-            # adjtable = pandas.DataFrame.from_dict(
-            #     dict(focal=heads, neighbor=tails, weight=weights)
-            # )
-            # adjtable = _induce_cliques(adjtable, coincident_lut, fill_value=0)
-            # return sparse.csr_array(
-            #     adjtable.weight.values,
-            #     (adjtable.focal.values, adjtable.neighbor.values),
-            #     shape=(n_samples, n_samples),
-            # )
+            adjtable = pandas.DataFrame.from_dict(
+                {"focal": heads, "neighbor": tails, "weight": weights}
+            )
+            adjtable = _induce_cliques(adjtable, coincident_lut, fill_value=-1)
+            adjtable = _reorder_adjtable_by_ids(adjtable, ids)
+            sparse_out = sparse.csr_array(
+                (
+                    adjtable.weight.values,
+                    (adjtable.focal.values, adjtable.neighbor.values),
+                ),
+                shape=(n_samples, n_samples),
+            )
+            sparse_out.data[sparse_out.data < 0] = 0
+            return sparse_out
         raise ValueError(
             f"'{coincident}' is not a valid option. Use one of "
             "['raise', 'jitter', 'clique']."
