@@ -15,14 +15,20 @@ from ._contiguity import (
     _vertex_set_intersection,
 )
 from ._kernel import _distance_band, _kernel
+from ._matching import _spatial_matching
 from ._parquet import _read_parquet, _to_parquet
 from ._plotting import _explore_graph, _plot
 from ._set_ops import SetOpsMixin
 from ._spatial_lag import _lag_spatial
 from ._triangulation import _delaunay, _gabriel, _relative_neighborhood, _voronoi
-from ._utils import _evaluate_index, _neighbor_dict_to_edges, _sparse_to_arrays
+from ._utils import (
+    _evaluate_index,
+    _neighbor_dict_to_edges,
+    _resolve_islands,
+    _sparse_to_arrays,
+)
 
-ALLOWED_TRANSFORMATIONS = ("O", "B", "R", "D", "V")
+ALLOWED_TRANSFORMATIONS = ("O", "B", "R", "D", "V", "C")
 
 # listed alphabetically
 __author__ = """"
@@ -40,7 +46,7 @@ class Graph(SetOpsMixin):
     and its API is incomplete and unstable.
     """
 
-    def __init__(self, adjacency, transformation="O"):
+    def __init__(self, adjacency, transformation="O", is_sorted=False):
         """Weights base class based on adjacency list
 
         It is recommenced to use one of the ``from_*`` or ``build_*`` constructors
@@ -63,6 +69,15 @@ class Graph(SetOpsMixin):
             - **R** -- Row-standardization (global sum :math:`=n`)
             - **D** -- Double-standardization (global sum :math:`=1`)
             - **V** -- Variance stabilizing
+            - **C** -- Custom
+        is_sorted : bool, default False
+            ``adjacency`` capturing the graph needs to be canonically sorted to
+            initialize the class. The MultiIndex needs to be ordered i-->j
+            on both focal and neighbor levels according to the order of ids in the
+            original data from which the Graph is created. Sorting is performed by
+            default based on the order of unique values in the focal level. Set
+            ``is_sorted=True`` to skip this step if the adjacency is already canonically
+            sorted.
 
         """
         if not isinstance(adjacency, pd.Series):
@@ -91,9 +106,12 @@ class Graph(SetOpsMixin):
                 f"'transformation' needs to be one of {ALLOWED_TRANSFORMATIONS}. "
                 f"'{transformation}' was given instead."
             )
-        # adjacency always ordered i-->j on both levels
-        ids = adjacency.index.get_level_values(0).unique().values
-        adjacency = adjacency.reindex(ids, level=0).reindex(ids, level=1)
+
+        if not is_sorted:
+            # adjacency always ordered i-->j on both levels
+            ids = adjacency.index.get_level_values(0).unique().values
+            adjacency = adjacency.reindex(ids, level=0).reindex(ids, level=1)
+
         self._adjacency = adjacency
         self.transformation = transformation
 
@@ -132,7 +150,9 @@ class Graph(SetOpsMixin):
             libpysal.graph.Graph as a copy of the original
         """
         return Graph(
-            self._adjacency.copy(deep=deep), transformation=self.transformation
+            self._adjacency.copy(deep=deep),
+            transformation=self.transformation,
+            is_sorted=True,
         )
 
     @cached_property
@@ -147,7 +167,7 @@ class Graph(SetOpsMixin):
         return self._adjacency.copy()
 
     @classmethod
-    def from_W(cls, w):  # noqa N802
+    def from_W(cls, w):  # noqa: N802
         """Create an experimental Graph from libpysal.weights.W object
 
         Parameters
@@ -161,7 +181,7 @@ class Graph(SetOpsMixin):
         """
         return cls.from_weights_dict(dict(w))
 
-    def to_W(self):  # noqa N802
+    def to_W(self):  # noqa: N802
         """Convert Graph to a libpysal.weights.W object
 
         Returns
@@ -261,7 +281,7 @@ class Graph(SetOpsMixin):
         return cls.from_arrays(*_sparse_to_arrays(sparse, ids))
 
     @classmethod
-    def from_arrays(cls, focal_ids, neighbor_ids, weight):
+    def from_arrays(cls, focal_ids, neighbor_ids, weight, **kwargs):
         """Generate Graph from arrays of indices and weights of the same length
 
         The arrays needs to be sorted in a way ensuring that focal_ids.unique() is
@@ -275,6 +295,8 @@ class Graph(SetOpsMixin):
             neighbor indices
         weight : array-like
             weights
+        **kwargs
+            keyword arguments passed to the class constructor
 
         Returns
         -------
@@ -289,7 +311,8 @@ class Graph(SetOpsMixin):
                 index=pd.MultiIndex.from_arrays(
                     [focal_ids, neighbor_ids], names=["focal", "neighbor"]
                 ),
-            )
+            ),
+            **kwargs,
         )
 
         return w
@@ -333,6 +356,30 @@ class Graph(SetOpsMixin):
         head, tail, weight = _neighbor_dict_to_edges(neighbors, weights=weights)
         return cls.from_arrays(head, tail, weight)
 
+    @classmethod
+    def build_block_contiguity(cls, regimes):
+        """Generate Graph from block contiguity (regime neighbors)
+
+        Block contiguity structures are relevant when defining neighbor relations
+        based on membership in a regime. For example, all counties belonging to
+        the same state could be defined as neighbors, in an analysis of all
+        counties in the US.
+
+        Parameters
+        ----------
+        regimes : list-like
+            list-like of regimes. If pandas.Series, its index is used to encode Graph.
+            Otherwise a default RangeIndex is used.
+
+        Returns
+        -------
+        Graph
+            libpysal.graph.Graph encoding block contiguity
+        """
+        ids = _evaluate_index(regimes)
+
+        return cls.from_dicts(_block_contiguity(regimes, ids=ids))
+
     @classmethod
     def build_contiguity(cls, geometry, rook=True, by_perimeter=False, strict=False):
         """Generate Graph from geometry based on contiguity
@@ -396,6 +443,156 @@ class Graph(SetOpsMixin):
             )
         )
 
+    @classmethod
+    def build_distance_band(
+        cls, data, threshold, binary=True, alpha=-1.0, kernel=None, bandwidth=None
+    ):
+        """Generate Graph from geometry based on a distance band
+
+        Parameters
+        ----------
+        data : numpy.ndarray, geopandas.GeoSeries, geopandas.GeoDataFrame
+            geometries containing locations to compute the
+            delaunay triangulation. If a geopandas object with Point
+            geometry is provided, the .geometry attribute is used. If a numpy.ndarray
+            with shapely geometry is used, then the coordinates are extracted and used.
+            If a numpy.ndarray of a shape (2,n) is used, it is assumed to contain x, y
+            coordinates.
+        threshold : float
+            distance band
+        binary : bool, optional
+            If True :math:`w_{ij}=1` if :math:`d_{i,j}<=threshold`, otherwise
+            :math:`w_{i,j}=0`.
+            If False :math:`wij=dij^{alpha}`, by default True.
+        alpha : float, optional
+            distance decay parameter for weight (default -1.0)
+            if alpha is positive the weights will not decline with
+            distance. Ignored if ``binary=True`` or ``kernel`` is not None.
+        kernel : str, optional
+            kernel function to use in order to weight the output graph. See
+            :meth:`Graph.build_kernel` for details. Ignored if ``binary=True``.
+        bandwidth : float (default: None)
+            distance to use in the kernel computation. Should be on the same scale as
+            the input coordinates. Ignored if ``binary=True`` or ``kernel=None``.
+
+        Returns
+        -------
+        Graph
+            libpysal.graph.Graph encoding distance band weights
+        """
+        ids = _evaluate_index(data)
+
+        dist = _distance_band(data, threshold)
+
+        if binary:
+            head, tail, weight = _kernel(
+                dist,
+                kernel="boxcar",
+                metric="precomputed",
+                ids=ids,
+                bandwidth=np.inf,
+            )
+        elif kernel is not None:
+            head, tail, weight = _kernel(
+                dist,
+                kernel=kernel,
+                metric="precomputed",
+                ids=ids,
+                bandwidth=bandwidth,
+            )
+        else:
+            head, tail, weight = _kernel(
+                dist,
+                kernel=lambda distances, alpha: np.power(distances, alpha),
+                metric="precomputed",
+                ids=ids,
+                bandwidth=alpha,
+            )
+
+        adjacency = pd.DataFrame.from_dict(
+            {"focal": head, "neighbor": tail, "weight": weight}
+        ).set_index("focal")
+
+        # drop diagonal
+        counts = adjacency.index.value_counts()
+        no_isolates = counts[counts > 1]
+        adjacency = adjacency[
+            ~(
+                adjacency.index.isin(no_isolates.index)
+                & (adjacency.index == adjacency.neighbor)
+            )
+        ]
+        # set isolates to 0 - distance band should never contain self-weight
+        adjacency.loc[~adjacency.index.isin(no_isolates.index), "weight"] = 0
+
+        return cls.from_arrays(
+            adjacency.index.values, adjacency.neighbor.values, adjacency.weight.values
+        )
+
+    @classmethod
+    def build_fuzzy_contiguity(
+        cls,
+        geometry,
+        tolerance=None,
+        buffer=None,
+        predicate="intersects",
+    ):
+        """Generate Graph from fuzzy contiguity
+
+        Fuzzy contiguity relaxes the notion of contiguity neighbors
+        for the case of geometry collections that violate the condition
+        of planar enforcement. It handles three types of conditions present
+        in such collections that would result in missing links when using
+        the regular contiguity methods.
+
+        The first are edges for nearby polygons that should be shared, but are
+        digitized separately for the individual polygons and the resulting edges
+        do not coincide, but instead the edges intersect. This case can also be
+        covered by ``build_contiguty`` with the ``strict=False`` parameter.
+
+        The second case is similar to the first, only the resultant edges do not
+        intersect but are "close". The optional buffering of geometry then closes the
+        gaps between the polygons and a resulting intersection is encoded as a link.
+
+        The final case arises when one polygon is "inside" a second polygon but is not
+        encoded to represent a hole in the containing polygon.
+
+        It is also possible to create a contiguity based on a custom spatial predicate.
+
+        Parameters
+        ----------
+        geoms :  array-like of shapely.Geometry objects
+            Could be geopandas.GeoSeries or geopandas.GeoDataFrame, in which case the
+            resulting Graph is indexed by the original index. If an array of
+            shapely.Geometry objects is passed, Graph will assume a RangeIndex.
+        tolerance : float, optional
+            The percentage of the length of the minimum side of the bounding rectangle
+            for the ``geoms`` to use in determining the buffering distance. Either
+            ``tolerance`` or ``buffer`` may be specified but not both.
+            By default None.
+        buffer : float, optional
+            Exact buffering distance in the units of ``geoms.crs``. Either
+            ``tolerance`` or ``buffer`` may be specified but not both.
+            By default None.
+        predicate : str, optional
+            The predicate to use for determination of neighbors. Default is
+            'intersects'. If None is passed, neighbours are determined based
+            on the intersection of bounding boxes. See the documentation of
+            ``geopandas.GeoSeries.sindex.query`` for allowed predicates.
+
+        Returns
+        -------
+        Graph
+            libpysal.graph.Graph encoding fuzzy contiguity
+        """
+        ids = _evaluate_index(geometry)
+
+        heads, tails, weights = _fuzzy_contiguity(
+            geometry, ids, tolerance=tolerance, buffer=buffer, predicate=predicate
+        )
+
+        return cls.from_arrays(heads, tails, weights)
+
     @classmethod
     def build_kernel(
         cls,
@@ -520,6 +717,78 @@ class Graph(SetOpsMixin):
 
         return cls.from_arrays(head, tail, weight)
 
+    @classmethod
+    def build_spatial_matches(
+        cls,
+        data,
+        k,
+        metric="euclidean",
+        solver=None,
+        allow_partial_match=False,
+        **metric_kwargs,
+    ):
+        """
+        Match locations in one dataset to at least `n_matches`
+        locations in another (possibly identical) dataset
+        by minimizing the total distance between matched locations.
+
+        Letting :math:`d_{ij}` be
+
+        .. math::
+
+            \\text{minimize} \\sum_i^n \\sum_j^n  d_{ij}m_{ij}
+
+            \\text{subject to}
+                \\sum_j^n m_{ij} >= k \\forall i
+
+                m_{ij} \\in {0,1} \\forall ij
+
+
+        Parameters
+        ----------
+        x : numpy.ndarray, geopandas.GeoSeries, geopandas.GeoDataFrame
+            geometries that need matches. If a geopandas.Geo* object
+            is provided, the .geometry attribute is used. If a numpy.ndarray with
+            a geometry dtype is used, then the coordinates are extracted and used.
+        y : numpy.ndarray, geopandas.GeoSeries, geopandas.GeoDataFrame (default: None)
+            geometries that are used as a source for matching. If a geopandas object
+            is provided, the .geometry attribute is used. If a numpy.ndarray with
+            a geometry dtype is used, then the coordinates are extracted and
+            used. If none, matches are made within `x`.
+        n_matches : int (default: None)
+            number of matches
+        metric : string or callable (default: 'euclidean')
+            distance function to apply over the input coordinates. Supported options
+            depend on whether or not scikit-learn is installed. If so, then any
+            distance function supported by scikit-learn is supported here. Otherwise,
+            only euclidean, minkowski, and manhattan/cityblock distances are admitted.
+        solver : solver from pulp (default: None)
+            a solver defined by the pulp optimization library. If no solver is
+            provided, pulp's default solver will be used. This is generally
+            pulp.COIN(), but this may vary depending on your configuration.
+        return_mip : bool (default: False)
+            whether or not to return the instance of the pulp.LpProblem. By
+            default, the problem is not returned to the user.
+        allow_partial_match : bool (default: False)
+            whether to allow for partial matching. A partial match may have
+            a weight between zero and one, while a "full" match (by default)
+            must have a weight of either zero or one. A partial matching may
+            have a shorter total distance, but will result in a weighted
+            graph.
+        """
+        head, tail, weight = _spatial_matching(
+            x=data,
+            metric=metric,
+            n_matches=k,
+            solver=solver,
+            allow_partial_match=allow_partial_match,
+            **metric_kwargs,
+        )
+        # ids need to be addressed here, rather than in the matching
+        # because x and y can have different id sets. It's only
+        # in W where we *know* we can just use one id vector.
+        return cls.from_arrays(head, tail, weight)
+
     @classmethod
     def build_triangulation(
         cls,
@@ -527,7 +796,7 @@ class Graph(SetOpsMixin):
         method="delaunay",
         bandwidth=np.inf,
         kernel="boxcar",
-        clip="extent",
+        clip="bounding_box",
         rook=True,
         coincident="raise",
     ):
@@ -558,20 +827,19 @@ class Graph(SetOpsMixin):
             :meth:`Graph.build_kernel` for details. By default "boxcar"
         clip : str (default: 'bbox')
             Clipping method when ``method="voronoi"``. Ignored otherwise.
-            Default is ``'extent'``. Options are as follows.
+            Default is ``'bounding_box'``. Options are as follows.
 
-            - ``'none'``/``None``: No clip is applied. Voronoi cells may be
-              arbitrarily larger that the source map. Note that this may lead to
-              cells that are many orders of magnitude larger in extent than the
-              original map. Not recommended.
-            - ``'bbox'``/``'extent'``/``'bounding box'``: Clip the voronoi cells to
-              the bounding box of the input points.
-            - ``'chull``/``'convex hull'``: Clip the voronoi cells to the convex hull
-              of the input points.
-            - ``'ashape'``/``'ahull'``: Clip the voronoi cells to the tightest hull
-              that contains all points (e.g. the smallest alphashape, using
-              :func:`libpysal.cg.alpha_shape_auto`).
-            - ``shapely.Polygon``: Clip to an arbitrary Polygon.
+            * ``None`` -- No clip is applied. Voronoi cells may be arbitrarily
+            larger that the source map. Note that this may lead to cells that are many
+            orders of magnitude larger in extent than the original map. Not recommended.
+            * ``'bounding_box'`` -- Clip the voronoi cells to the
+            bounding box of the input points.
+            * ``'convex_hull'`` -- Clip the voronoi cells to the convex hull of
+            the input points.
+            * ``'alpha_shape'`` -- Clip the voronoi cells to the tightest hull that
+            contains all points (e.g. the smallest alpha shape, using
+            :func:`libpysal.cg.alpha_shape_auto`).
+            * ``shapely.Polygon`` -- Clip to an arbitrary Polygon.
 
         rook : bool, optional
             Contiguity method when ``method="voronoi"``. Ignored otherwise.
@@ -615,180 +883,6 @@ class Graph(SetOpsMixin):
 
         return cls.from_arrays(head, tail, weights)
 
-    @classmethod
-    def build_distance_band(
-        cls, data, threshold, binary=True, alpha=-1.0, kernel=None, bandwidth=None
-    ):
-        """Generate Graph from geometry based on a distance band
-
-        Parameters
-        ----------
-        data : numpy.ndarray, geopandas.GeoSeries, geopandas.GeoDataFrame
-            geometries containing locations to compute the
-            delaunay triangulation. If a geopandas object with Point
-            geometry is provided, the .geometry attribute is used. If a numpy.ndarray
-            with shapely geometry is used, then the coordinates are extracted and used.
-            If a numpy.ndarray of a shape (2,n) is used, it is assumed to contain x, y
-            coordinates.
-        threshold : float
-            distance band
-        binary : bool, optional
-            If True :math:`w_{ij}=1` if :math:`d_{i,j}<=threshold`, otherwise
-            :math:`w_{i,j}=0`.
-            If False :math:`wij=dij^{alpha}`, by default True.
-        alpha : float, optional
-            distance decay parameter for weight (default -1.0)
-            if alpha is positive the weights will not decline with
-            distance. Ignored if ``binary=True`` or ``kernel`` is not None.
-        kernel : str, optional
-            kernel function to use in order to weight the output graph. See
-            :meth:`Graph.build_kernel` for details. Ignored if ``binary=True``.
-        bandwidth : float (default: None)
-            distance to use in the kernel computation. Should be on the same scale as
-            the input coordinates. Ignored if ``binary=True`` or ``kernel=None``.
-
-        Returns
-        -------
-        Graph
-            libpysal.graph.Graph encoding distance band weights
-        """
-        ids = _evaluate_index(data)
-
-        dist = _distance_band(data, threshold)
-
-        if binary:
-            head, tail, weight = _kernel(
-                dist,
-                kernel="boxcar",
-                metric="precomputed",
-                ids=ids,
-                bandwidth=np.inf,
-            )
-        elif kernel is not None:
-            head, tail, weight = _kernel(
-                dist,
-                kernel=kernel,
-                metric="precomputed",
-                ids=ids,
-                bandwidth=bandwidth,
-            )
-        else:
-            head, tail, weight = _kernel(
-                dist,
-                kernel=lambda distances, alpha: np.power(distances, alpha),
-                metric="precomputed",
-                ids=ids,
-                bandwidth=alpha,
-            )
-
-        adjacency = pd.DataFrame.from_dict(
-            {"focal": head, "neighbor": tail, "weight": weight}
-        ).set_index("focal")
-
-        # drop diagonal
-        counts = adjacency.index.value_counts()
-        no_isolates = counts[counts > 1]
-        adjacency = adjacency[
-            ~(
-                adjacency.index.isin(no_isolates.index)
-                & (adjacency.index == adjacency.neighbor)
-            )
-        ]
-        # set isolates to 0 - distance band should never contain self-weight
-        adjacency.loc[~adjacency.index.isin(no_isolates.index), "weight"] = 0
-
-        return cls.from_arrays(
-            adjacency.index.values, adjacency.neighbor.values, adjacency.weight.values
-        )
-
-    @classmethod
-    def build_block_contiguity(cls, regimes):
-        """Generate Graph from block contiguity (regime neighbors)
-
-        Block contiguity structures are relevant when defining neighbor relations
-        based on membership in a regime. For example, all counties belonging to
-        the same state could be defined as neighbors, in an analysis of all
-        counties in the US.
-
-        Parameters
-        ----------
-        regimes : list-like
-            list-like of regimes. If pandas.Series, its index is used to encode Graph.
-            Otherwise a default RangeIndex is used.
-
-        Returns
-        -------
-        Graph
-            libpysal.graph.Graph encoding block contiguity
-        """
-        ids = _evaluate_index(regimes)
-
-        return cls.from_dicts(_block_contiguity(regimes, ids=ids))
-
-    @classmethod
-    def build_fuzzy_contiguity(
-        cls,
-        geometry,
-        tolerance=None,
-        buffer=None,
-        predicate="intersects",
-    ):
-        """Generate Graph from fuzzy contiguity
-
-        Fuzzy contiguity relaxes the notion of contiguity neighbors
-        for the case of geometry collections that violate the condition
-        of planar enforcement. It handles three types of conditions present
-        in such collections that would result in missing links when using
-        the regular contiguity methods.
-
-        The first are edges for nearby polygons that should be shared, but are
-        digitized separately for the individual polygons and the resulting edges
-        do not coincide, but instead the edges intersect. This case can also be
-        covered by ``build_contiguty`` with the ``strict=False`` parameter.
-
-        The second case is similar to the first, only the resultant edges do not
-        intersect but are "close". The optional buffering of geometry then closes the
-        gaps between the polygons and a resulting intersection is encoded as a link.
-
-        The final case arises when one polygon is "inside" a second polygon but is not
-        encoded to represent a hole in the containing polygon.
-
-        It is also possible to create a contiguity based on a custom spatial predicate.
-
-        Parameters
-        ----------
-        geoms :  array-like of shapely.Geometry objects
-            Could be geopandas.GeoSeries or geopandas.GeoDataFrame, in which case the
-            resulting Graph is indexed by the original index. If an array of
-            shapely.Geometry objects is passed, Graph will assume a RangeIndex.
-        tolerance : float, optional
-            The percentage of the length of the minimum side of the bounding rectangle
-            for the ``geoms`` to use in determining the buffering distance. Either
-            ``tolerance`` or ``buffer`` may be specified but not both.
-            By default None.
-        buffer : float, optional
-            Exact buffering distance in the units of ``geoms.crs``. Either
-            ``tolerance`` or ``buffer`` may be specified but not both.
-            By default None.
-        predicate : str, optional
-            The predicate to use for determination of neighbors. Default is
-            'intersects'. If None is passed, neighbours are determined based
-            on the intersection of bounding boxes. See the documentation of
-            ``geopandas.GeoSeries.sindex.query`` for allowed predicates.
-
-        Returns
-        -------
-        Graph
-            libpysal.graph.Graph encoding fuzzy contiguity
-        """
-        ids = _evaluate_index(geometry)
-
-        heads, tails, weights = _fuzzy_contiguity(
-            geometry, ids, tolerance=tolerance, buffer=buffer, predicate=predicate
-        )
-
-        return cls.from_arrays(heads, tails, weights)
-
     @cached_property
     def neighbors(self):
         """Get neighbors dictionary
@@ -862,7 +956,7 @@ class Graph(SetOpsMixin):
 
         Parameters
         ----------
-        transformation : str
+        transformation : str | callable
             Transformation method. The following are
             valid transformations.
 
@@ -871,6 +965,9 @@ class Graph(SetOpsMixin):
             - **D** -- Double-standardization (global sum :math:`=1`)
             - **V** -- Variance stabilizing
 
+            Alternatively, you can pass your own callable passed to
+            ``self.adjacency.groupby(level=0).transform()``.
+
         Returns
         -------
         Graph
@@ -881,7 +978,8 @@ class Graph(SetOpsMixin):
         ValueError
             Value error for unsupported transformation
         """
-        transformation = transformation.upper()
+        if isinstance(transformation, str):
+            transformation = transformation.upper()
 
         if self.transformation == transformation:
             return self.copy()
@@ -906,16 +1004,20 @@ class Graph(SetOpsMixin):
             n_q = self.n / s.sum()
             standardized = (s * n_q).fillna(0).values  # isolate comes as NaN -> 0
 
+        elif callable(transformation):
+            standardized = self._adjacency.groupby(level=0).transform(transformation)
+            transformation = "C"
+
         else:
             raise ValueError(
                 f"Transformation '{transformation}' is not supported. "
-                f"Use one of {ALLOWED_TRANSFORMATIONS[1:]}"
+                f"Use one of {ALLOWED_TRANSFORMATIONS[1:]} or pass a callable."
             )
 
         standardized_adjacency = pd.Series(
             standardized, name="weight", index=self._adjacency.index
         )
-        return Graph(standardized_adjacency, transformation)
+        return Graph(standardized_adjacency, transformation, is_sorted=True)
 
     @cached_property
     def _components(self):
@@ -972,9 +1074,13 @@ class Graph(SetOpsMixin):
         pandas.Index
             Index with a subset of observations that do not have any neighbor
         """
-        nulls = self._adjacency[self._adjacency == 0].reset_index(level=1)
+        nulls = self._adjacency[self._adjacency == 0]
         # since not all zeros are necessarily isolates, do the focal == neighbor check
-        return nulls[nulls.index == nulls.neighbor].index.unique()
+        return (
+            nulls[nulls.index.codes[0] == nulls.index.codes[1]]
+            .index.get_level_values(0)
+            .unique()
+        )
 
     @cached_property
     def unique_ids(self):
@@ -1337,6 +1443,144 @@ class Graph(SetOpsMixin):
             **kwargs,
         )
 
+    def subgraph(self, ids):
+        """Returns a subset of Graph containing only nodes specified in ids
+
+        The resulting subgraph contains only the nodes in ``ids`` and the edges
+        between them or zero-weight self-loops in case of isolates.
+
+        The order of ``ids`` reflects a new canonical order of the resulting
+        subgraph. This means ``ids`` should be equal to the index of the DataFrame
+        containing data linked to the graph to ensure alignment of sparse representation
+        of subgraph.
+
+        Parameters
+        ----------
+        ids : array-like
+            An array of node IDs to be retained
+
+        Returns
+        -------
+        Graph
+            A new Graph that is a subset of the original
+
+        Notes
+        -----
+        Unlike the implementation in ``networkx``, this creates a copy since
+        Graphs in ``libpysal`` are immutable.
+        """
+        masked_adj = self._adjacency[ids]
+        filtered_adj = masked_adj[
+            masked_adj.index.get_level_values("neighbor").isin(ids)
+        ]
+        return Graph.from_arrays(
+            *_resolve_islands(
+                filtered_adj.index.get_level_values("focal"),
+                filtered_adj.index.get_level_values("neighbor"),
+                ids,
+                filtered_adj.values,
+            )
+        )
+
+    def eliminate_zeros(self):
+        """Remove graph edges with zero weight
+
+        Eliminates edges with weight == 0 that do not encode an
+        isolate. This is useful to clean-up edges that will make
+        no effect in operations like :meth:`lag`.
+
+        Returns
+        -------
+        Graph
+            subset of Graph with zero-weight edges eliminated
+        """
+        # get a mask for isolates
+        isolates = self._adjacency.index.codes[0] == self._adjacency.index.codes[1]
+        # substract isolates from mask of zeros
+        zeros = (self._adjacency == 0) != isolates
+        return Graph(self._adjacency[~zeros], is_sorted=True)
+
+    def assign_self_weight(self, weight=1):
+        """Assign values to edges representing self-weight.
+
+        The value for each ``focal == neighbor`` location in
+        the graph is set to ``weight``.
+
+        Parameters
+        ----------
+        weight : float | array-like
+            Defines the value(s) to which the weight representing the relationship with
+            itself should be set. If a constant is passed then each self-weight will get
+            this value (default is 1). An array of length ``Graph.n`` can be passed to
+            set explicit values to each self-weight (assumed to be in the same order as
+            original data).
+
+        Returns
+        -------
+        Graph
+            A new ``Graph`` with added self-weights.
+        """
+        addition = pd.Series(
+            weight,
+            index=pd.MultiIndex.from_arrays(
+                [self.unique_ids, self.unique_ids], names=["focal", "neighbor"]
+            ),
+            name="weight",
+        )
+        adj = (
+            pd.concat([self.adjacency.drop(self.isolates), addition])
+            .reindex(self.unique_ids, level=0)
+            .reindex(self.unique_ids, level=1)
+        )
+        return Graph(adj, is_sorted=True)
+
+    def apply(self, y, func, **kwargs):
+        """Apply a reduction across the neighbor sets
+
+        Applies ``func`` over groups of ``y`` defined by neighbors for each focal.
+
+        Parameters
+        ----------
+        y : array_like
+            array of values to be grouped. Can be 1-D or 2-D and will be coerced to a
+            pandas object
+        func : function, str, list, dict or None
+            Function to use for aggregating the data passed to pandas ``GroupBy.apply``.
+
+        Returns
+        -------
+        Series | DataFrame
+            pandas object indexed by unique_ids
+        """
+        if not isinstance(y, pd.Series | pd.DataFrame):
+            y = pd.DataFrame(y) if hasattr(y, "ndim") and y.ndim == 2 else pd.Series(y)
+        grouper = y.take(self._adjacency.index.codes[1]).groupby(
+            self._adjacency.index.codes[0]
+        )
+        result = grouper.apply(func, **kwargs)
+        result.index = self.unique_ids
+        if isinstance(result, pd.Series):
+            result.name = None
+        return result
+
+    def aggregate(self, func):
+        """Aggregate weights within a neighbor set
+
+        Apply a custom aggregation function to a group of weights of the same focal
+        geometry.
+
+        Parameters
+        ----------
+        func : callable
+            A callable accepted by pandas ``groupby.agg`` method
+
+        Returns
+        -------
+        pd.Series
+            Aggregated weights
+        """
+        return self._adjacency.groupby(level=0).agg(func)
+
 
 def _arrange_arrays(heads, tails, weights, ids=None):
     """
@@ -1385,4 +1629,4 @@ def read_parquet(path, **kwargs):
         deserialized Graph
     """
     adjacency, transformation = _read_parquet(path, **kwargs)
-    return Graph(adjacency, transformation)
+    return Graph(adjacency, transformation, is_sorted=True)
