@@ -248,14 +248,14 @@ class TestKernel:
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
     def test_knn_intids(self):
-        g = graph.Graph.build_knn(self.gdf, k=3)
+        g = graph.Graph.build_knn(self.gdf, k=3, coincident="jitter")
 
         assert pd.api.types.is_numeric_dtype(g._adjacency.index.dtypes["focal"])
         assert pd.api.types.is_numeric_dtype(g._adjacency.index.dtypes["neighbor"])
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
     def test_knn_strids(self):
-        g = graph.Graph.build_kernel(self.gdf_str, k=3)
+        g = graph.Graph.build_kernel(self.gdf_str, k=3, coincident="jitter")
 
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["focal"])
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["neighbor"])
@@ -443,3 +443,26 @@ class TestAdjacency:
         contiguity_str = graph.Graph.build_contiguity(self.gdf_str)
         built_str = graph.Graph.from_adjacency(self.expected_adjacency_strid)
         assert contiguity_str == built_str
+
+
+class TestMatching:
+    def setup_method(self):
+        pytest.importorskip("pulp")
+        self.gdf = gpd.read_file(geodatasets.get_path("nybb"))
+        self.gdf = self.gdf.set_geometry(self.gdf.centroid)
+        self.gdf_str = self.gdf.set_index("BoroName")
+        self.gdf_str = self.gdf_str.set_geometry(self.gdf_str.centroid)
+
+    def test_matching_intids(self):
+        g = graph.Graph.build_spatial_matches(self.gdf, k=1)
+
+        assert pd.api.types.is_numeric_dtype(g._adjacency.index.dtypes["focal"])
+        assert pd.api.types.is_numeric_dtype(g._adjacency.index.dtypes["neighbor"])
+        assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
+
+    def test_matching_strids(self):
+        g = graph.Graph.build_spatial_matches(self.gdf_str, k=2)
+
+        assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["focal"])
+        assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["neighbor"])
+        assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
