@@ -1,11 +1,12 @@
-from .. import tables
-from ...common import MISSINGVALUE
+# ruff: noqa: N802, N806, N816, N999, SIM115
+
 import datetime
-import struct
 import os
+import struct
 import time
 
-from typing import Union
+from ...common import MISSINGVALUE
+from .. import tables
 
 __author__ = "Charles R Schmidt <schmidtc@gmail.com>"
 __all__ = ["DBF"]
@@ -71,7 +72,7 @@ class DBF(tables.DataTable):
             self._col_index = {}
             idx = 0
 
-            for fieldno in range(numfields):
+            for _ in range(numfields):
                 # again, check struct for fmt def.
                 name, typ, size, deci = struct.unpack("<11sc4xBB14x", f.read(32))
                 # forces to unicode in 2, to str in 3
@@ -98,7 +99,7 @@ class DBF(tables.DataTable):
             self.header = [fInfo[0] for fInfo in self.field_info[1:]]
             field_spec = []
 
-            for fname, ftype, flen, fpre in self.field_info[1:]:
+            for _, ftype, flen, fpre in self.field_info[1:]:
                 field_spec.append((ftype, flen, fpre))
 
             self.field_spec = field_spec
@@ -124,7 +125,7 @@ class DBF(tables.DataTable):
 
         if self.mode != "r":
             msg = "Invalid operation, cannot read from a file opened in 'w' mode."
-            raise IOError(msg)
+            raise OSError(msg)
 
         return self.n_records
 
@@ -182,11 +183,8 @@ class DBF(tables.DataTable):
                 value = (value in "YyTt" and "T") or (value in "NnFf" and "F") or "?"
             elif typ == "F":
                 value = value.replace("\0", "").lstrip()
-                if value == "":
-                    value = MISSINGVALUE
-                else:
-                    value = float(value)
-            if isinstance(value, str) or isinstance(value, str):
+                value = MISSINGVALUE if value == "" else float(value)
+            if isinstance(value, str | str):
                 value = value.rstrip()
             col[i] = value
 
@@ -204,7 +202,7 @@ class DBF(tables.DataTable):
             return self.read_record(i + 1)
         result = []
 
-        for (name, typ, size, deci), value in zip(self.field_info, rec):
+        for (name, typ, _, deci), value in zip(self.field_info, rec, strict=True):
             if name == "DeletionFlag":
                 continue
             if typ == "N":
@@ -232,17 +230,14 @@ class DBF(tables.DataTable):
                 value = (value in "YyTt" and "T") or (value in "NnFf" and "F") or "?"
             elif typ == "F":
                 value = value.replace("\0", "").lstrip()
-                if value == "":
-                    value = MISSINGVALUE
-                else:
-                    value = float(value)
-            if isinstance(value, str) or isinstance(value, str):
+                value = MISSINGVALUE if value == "" else float(value)
+            if isinstance(value, str | str):
                 value = value.rstrip()
             result.append(value)
 
         return result
 
-    def _read(self) -> Union[list, None]:
+    def _read(self) -> list | None:
         """
 
         Raises
@@ -254,7 +249,7 @@ class DBF(tables.DataTable):
 
         if self.mode != "r":
             msg = "Invalid operation, cannot read from a file opened in 'w' mode."
-            raise IOError(msg)
+            raise OSError(msg)
 
         if self.pos < len(self):
             rec = self.read_record(self.pos)
@@ -279,7 +274,7 @@ class DBF(tables.DataTable):
 
         if self.mode != "w":
             msg = "Invalid operation, cannot read from a file opened in 'r' mode."
-            raise IOError(msg)
+            raise OSError(msg)
 
         if self.FIRST_WRITE:
             self._firstWrite()
@@ -290,19 +285,16 @@ class DBF(tables.DataTable):
         self.numrec += 1
 
         # deletion flag
-        self.f.write(" ".encode())
+        self.f.write(b" ")
 
-        for (typ, size, deci), value in zip(self.field_spec, obj):
+        for (typ, size, deci), value in zip(self.field_spec, obj, strict=True):
             if value is None:
-                if typ == "C":
-                    value = " " * size
-                else:
-                    value = "\0" * size
+                value = " " * size if typ == "C" else "\x00" * size
             elif typ == "N" or typ == "F":
-                v = str(value).rjust(size, " ")
-                # if len(v) == size:
-                #    value = v
-                # else:
+                # v = str(value).rjust(size, " ")
+                # # if len(v) == size:
+                # #    value = v
+                # # else:
                 value = (("%" + "%d.%d" % (size, deci) + "f") % (value))[:size]
             elif typ == "D":
                 value = value.strftime("%Y%m%d")
@@ -327,7 +319,7 @@ class DBF(tables.DataTable):
         if self.mode == "w":
             self.flush()
             # End of file
-            self.f.write("\x1A".encode())
+            self.f.write(b"\x1A")
         self.f.close()
 
         tables.DataTable.close(self)
@@ -345,9 +337,9 @@ class DBF(tables.DataTable):
         """
 
         if not self.header:
-            raise IOError("No header, DBF files require a header.")
+            raise OSError("No header, DBF files require a header.")
         if not self.field_spec:
-            raise IOError("No field_spec, DBF files require a specification.")
+            raise OSError("No field_spec, DBF files require a specification.")
 
         self._writeHeader()
 
@@ -377,7 +369,7 @@ class DBF(tables.DataTable):
         self.f.write(hdr)
 
         # field specs
-        for name, (typ, size, deci) in zip(self.header, self.field_spec):
+        for name, (typ, size, deci) in zip(self.header, self.field_spec, strict=True):
             typ = typ.encode()
             name = name.ljust(11, "\x00")
             name = name.encode()
@@ -385,7 +377,7 @@ class DBF(tables.DataTable):
             self.f.write(fld)
 
         # terminator
-        term = "\r".encode()
+        term = b"\r"
         self.f.write(term)
         if self.f.tell() != POS and not self.FIRST_WRITE:
             self.f.seek(POS)
