@@ -4,11 +4,11 @@ import tempfile
 import pytest
 
 from .... import examples as pysal_examples
-from ...fileio import FileIO as psopen
+from ...fileio import FileIO
 from ..gal import GalIO
 
 
-class Testtest_GalIO:
+class TesttestGalIO:
     def setup_method(self):
         self.test_file = test_file = pysal_examples.get_path("sids2.gal")
         self.obj = GalIO(test_file, "r")
@@ -40,8 +40,8 @@ class Testtest_GalIO:
         f = tempfile.NamedTemporaryFile(suffix=".gal")
         fname = f.name
         f.close()
-        o = psopen(fname, "w")
+        o = FileIO(fname, "w")
         o.write(w)
         o.close()
-        wnew = psopen(fname, "r").read()
+        wnew = FileIO(fname, "r").read()
         assert wnew.pct_nonzero == w.pct_nonzero
