@@ -1,26 +1,30 @@
-from ..io.fileio import FileIO as psopen
-from .weights import W, WSP
-from .set_operations import w_subset
-import numpy as np
-from scipy import sparse
-from scipy.spatial import KDTree
 import copy
-import scipy.spatial
-import os
-import scipy
-from warnings import warn
 import numbers
+import os
 from collections import defaultdict
 from itertools import tee
-from ..common import requires
+from warnings import warn
+
+import numpy as np
+
+# ruff: noqa: N802, N803
+import scipy
+import scipy.spatial
 from packaging.version import Version
+from scipy import sparse
+from scipy.spatial import KDTree
+
+from ..common import requires
+from ..io.fileio import FileIO
+from .set_operations import w_subset
+from .weights import WSP, W
 
 try:
     import geopandas as gpd
 
     GPD_013 = Version(gpd.__version__) >= Version("0.13.0")
 except ImportError:
-    warn("geopandas not available. Some functionality will be disabled.")
+    warn("geopandas not available. Some functionality will be disabled.", stacklevel=2)
 
 try:
     from shapely.geometry.base import BaseGeometry
@@ -72,7 +76,6 @@ def hexLat2W(nrows=5, ncols=5, **kwargs):
     **kwargs   : keyword arguments
                  optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
     w : W
@@ -80,7 +83,8 @@ def hexLat2W(nrows=5, ncols=5, **kwargs):
 
     Notes
     -----
-    Observations are row ordered: first k observations are in row 0, next k in row 1, and so on.
+    Observations are row ordered: first k observations are in row 0,
+    next k in row 1, and so on.
 
     Construction is based on shifting every other column of a regular lattice
     down 1/2 of a cell.
@@ -149,7 +153,6 @@ def lat2W(nrows=5, ncols=5, rook=True, id_type="int", **kwargs):
 
     Parameters
     ----------
-
     nrows      : int
                  number of rows
     ncols      : int
@@ -163,21 +166,18 @@ def lat2W(nrows=5, ncols=5, rook=True, id_type="int", **kwargs):
     **kwargs   : keyword arguments
                  optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
-
     w : W
         instance of spatial weights class W
 
     Notes
     -----
-
-    Observations are row ordered: first k observations are in row 0, next k in row 1, and so on.
+    Observations are row ordered: first k observations are in row 0,
+    next k in row 1, and so on.
 
     Examples
     --------
-
     >>> from libpysal.weights import lat2W
     >>> w9 = lat2W(3,3)
     >>> "%.3f"%w9.pct_nonzero
@@ -217,7 +217,6 @@ def lat2W(nrows=5, ncols=5, rook=True, id_type="int", **kwargs):
                 w[i] = w.get(i, []) + [r]
                 w[r] = w.get(r, []) + [i]
 
-    neighbors = {}
     weights = {}
     for key in w:
         weights[key] = [1.0] * len(w[key])
@@ -227,7 +226,7 @@ def lat2W(nrows=5, ncols=5, rook=True, id_type="int", **kwargs):
     elif id_type == "float":
         ids = [i * 1.0 for i in ids]
     if id_type == "string" or id_type == "float":
-        id_dict = dict(list(zip(list(range(n)), ids)))
+        id_dict = dict(list(zip(list(range(n)), ids, strict=True)))
         alt_w = {}
         alt_weights = {}
         for i in w:
@@ -261,10 +260,8 @@ def block_weights(regimes, ids=None, sparse=False, **kwargs):
     **kwargs    : keyword arguments
                   optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
-
     W : spatial weights instance
 
     Examples
@@ -287,15 +284,15 @@ def block_weights(regimes, ids=None, sparse=False, **kwargs):
     >>> w = block_weights(regimes)
     >>> w.neighbors == {0: [1], 1: [0], 2: [3], 3: [2], 4: [5, 8], 5: [4, 8], 6: [7], 7: [6], 8: [4, 5]}
     True
-    """
+    """  # noqa: E501
     rids = np.unique(regimes)
     neighbors = {}
-    NPNZ = np.nonzero
+    npnz = np.nonzero
     regimes = np.array(regimes)
     for rid in rids:
-        members = NPNZ(regimes == rid)[0]
+        members = npnz(regimes == rid)[0]
         for member in members:
-            neighbors[member] = members[NPNZ(members != member)[0]].tolist()
+            neighbors[member] = members[npnz(members != member)[0]].tolist()
     w = W(neighbors, **kwargs)
     if ids is not None:
         w.remap_ids(ids)
@@ -310,7 +307,6 @@ def comb(items, n=None):
 
     Parameters
     ----------
-
     items : list
             items to be drawn from
     n     : integer
@@ -318,7 +314,6 @@ def comb(items, n=None):
 
     Returns
     -------
-
     implicit : generator
                combinations of size n taken from items
 
@@ -334,7 +329,6 @@ def comb(items, n=None):
     [1, 2]
     [1, 3]
     [2, 3]
-
     """
     items = list(items)
     if n is None:
@@ -356,7 +350,6 @@ def order(w, kmax=3):
 
     Parameters
     ----------
-
     w       : W
               spatial weights object
 
@@ -365,7 +358,6 @@ def order(w, kmax=3):
 
     Returns
     -------
-
     info : dictionary
            observation id is the key, value is a list of contiguity
            orders with a negative 1 in the ith position
@@ -385,7 +377,6 @@ def order(w, kmax=3):
     >>> w3 = order(w, kmax = 3)
     >>> w3[1][0:5]
     [1, -1, 1, 2, 1]
-
     """
 
     ids = w.id_order
@@ -419,7 +410,6 @@ def higher_order(w, k=2, **kwargs):
 
     Parameters
     ----------
-
     w        : W
                spatial weights object
     k        : int
@@ -429,7 +419,6 @@ def higher_order(w, k=2, **kwargs):
 
     Returns
     -------
-
     implicit : W
                spatial weights object
 
@@ -489,10 +478,8 @@ def higher_order_sp(
     wk : W
              WSP, type matches type of w argument
 
-
     Examples
     --------
-
     >>> from libpysal.weights import lat2W, higher_order_sp
     >>> w25 = lat2W(5,5)
     >>> w25.n
@@ -512,9 +499,10 @@ def higher_order_sp(
     >>> w25_3[0] == {1: 1.0, 3: 1.0, 5: 1.0, 7: 1.0, 11: 1.0, 15: 1.0}
     True
     >>> w25_3 = higher_order_sp(w25, 3, lower_order=True)
-    >>> w25_3[0] == {5: 1.0, 7: 1.0, 11: 1.0, 2: 1.0, 15: 1.0, 6: 1.0, 10: 1.0, 1: 1.0, 3: 1.0}
+    >>> w25_3[0] == {
+    ...     5: 1.0, 7: 1.0, 11: 1.0, 2: 1.0, 15: 1.0, 6: 1.0, 10: 1.0, 1: 1.0, 3: 1.0
+    ... }
     True
-
     """
     id_order = None
     if issubclass(type(w), W) or isinstance(w, W):
@@ -535,26 +523,26 @@ def higher_order_sp(
         )
 
     if lower_order:
-        wk = sum(map(lambda x: w**x, range(2, k + 1)))
+        wk = sum(w**x for x in range(2, k + 1))
         shortest_path = False
     else:
         wk = w**k
 
     rk, ck = wk.nonzero()
-    sk = set(zip(rk, ck))
+    sk = set(zip(rk, ck, strict=True))
 
     if shortest_path:
         for j in range(1, k):
             wj = w**j
             rj, cj = wj.nonzero()
-            sj = set(zip(rj, cj))
+            sj = set(zip(rj, cj, strict=True))
             sk.difference_update(sj)
 
     if not diagonal:
-        sk = set([(i, j) for i, j in sk if i != j])
+        sk = {(i, j) for i, j in sk if i != j}
 
     if id_order:
-        d = dict([(i, []) for i in id_order])
+        d = {i: [] for i in id_order}
         for pair in sk:
             k, v = pair
             k = id_order[k]
@@ -578,20 +566,17 @@ def w_local_cluster(w):
 
     Parameters
     ----------
-
     w   : W
           spatial weights object
 
     Returns
     -------
-
     c     : array
             (w.n,1)
             local clustering coefficients
 
     Notes
     -----
-
     The local clustering coefficient :math:`c_i` quantifies how close the
     neighbors of observation :math:`i` are to being a clique:
 
@@ -617,15 +602,14 @@ def w_local_cluster(w):
            [1.        ],
            [0.6       ],
            [1.        ]])
-
     """
 
     c = np.zeros((w.n, 1), float)
     w.transformation = "b"
-    for i, id in enumerate(w.id_order):
-        ki = max(w.cardinalities[id], 1)  # deal with islands
-        Ni = w.neighbors[id]
-        wi = w_subset(w, Ni).full()[0]
+    for i, id_ in enumerate(w.id_order):
+        ki = max(w.cardinalities[id_], 1)  # deal with islands
+        ni = w.neighbors[id_]
+        wi = w_subset(w, ni).full()[0]
         c[i] = wi.sum() / (ki * (ki - 1))
     return c
 
@@ -641,7 +625,6 @@ def shimbel(w):
 
     Returns
     -------
-
     info  : list
             list of lists; one list for each observation which stores
             the shortest order between it and each of the the other observations.
@@ -669,7 +652,7 @@ def shimbel(w):
         while flag:
             p = -1
             knext = k + 1
-            for j in range(s.count(k)):
+            for _ in range(s.count(k)):
                 neighbor = s.index(k, p + 1)
                 p = neighbor
                 next_neighbors = w.neighbors[ids[p]]
@@ -728,7 +711,6 @@ def full2W(m, ids=None, **kwargs):
     **kwargs   : keyword arguments
                  optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
     w       : W
@@ -823,8 +805,6 @@ def WSP2W(wsp, **kwargs):
     10
     >>> print(w.full()[0][0])
     [0. 1. 0. 0. 0. 1. 0. 0. 0. 0.]
-
-
     """
     data = wsp.sparse.data
     indptr = wsp.sparse.indptr
@@ -850,7 +830,7 @@ def WSP2W(wsp, **kwargs):
 
 
 def insert_diagonal(w, val=1.0, wsp=False):
-    warn("This function is deprecated. Use fill_diagonal instead.")
+    warn("This function is deprecated. Use fill_diagonal instead.", stacklevel=2)
     return fill_diagonal(w, val=val, wsp=wsp)
 
 
@@ -900,7 +880,6 @@ def fill_diagonal(w, val=1.0, wsp=False):
     >>> w_var = insert_diagonal(w, diag)
     >>> w_var['id0'] == {'id5': 1.0, 'id0': 100.0, 'id1': 1.0}
     True
-
     """
 
     w_new = copy.deepcopy(w.sparse)
@@ -920,7 +899,7 @@ def fill_diagonal(w, val=1.0, wsp=False):
         return WSP2W(w_out)
 
 
-def remap_ids(w, old2new, id_order=[], **kwargs):
+def remap_ids(w, old2new, id_order=[], **kwargs):  # noqa: B006
     """
     Remaps the IDs in a spatial weights object.
 
@@ -928,11 +907,9 @@ def remap_ids(w, old2new, id_order=[], **kwargs):
     ----------
     w        : W
                Spatial weights object
-
     old2new  : dictionary
                Dictionary where the keys are the IDs in w (i.e. "old IDs") and
                the values are the IDs to replace them (i.e. "new IDs")
-
     id_order : list
                An ordered list of new IDs, which defines the order of observations when
                iterating over W. If not set then the id_order in w will be
@@ -940,10 +917,8 @@ def remap_ids(w, old2new, id_order=[], **kwargs):
     **kwargs : keyword arguments
                optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
-
     implicit : W
                Spatial weights object with new IDs
 
@@ -961,7 +936,6 @@ def remap_ids(w, old2new, id_order=[], **kwargs):
     ['a', 'b', 'c', 'd', 'e', 'f']
     >>> w_new.neighbors['a']
     ['c', 'b']
-
     """
 
     if not isinstance(w, W):
@@ -1023,13 +997,12 @@ def get_ids(in_shps, idVariable):
     3    4
     4    5
     Name: POLYID, dtype: int64
-
     """
 
     try:
-        if type(in_shps) == str:
+        if isinstance(in_shps, str):
             dbname = os.path.splitext(in_shps)[0] + ".dbf"
-            db = psopen(dbname)
+            db = FileIO(dbname)
             cols = db.header
             var = db.by_col[idVariable]
             db.close()
@@ -1038,23 +1011,24 @@ def get_ids(in_shps, idVariable):
             var = list(in_shps[idVariable])
         return var
 
-    except IOError:
+    except OSError:
         msg = (
-            'The shapefile "%s" appears to be missing its DBF file. '
-            + ' The DBF file "%s" could not be found.' % (in_shps, dbname)
+            f'The shapefile "{in_shps}" appears to be missing its DBF file. '
+            f' The DBF file "{dbname}" could not be found.'
         )
-        raise IOError(msg)
+        raise OSError(msg) from None
     except (AttributeError, KeyError):
         msg = (
-            'The variable "%s" not found in the DBF/GDF. The the following '
-            + "variables are present: %s." % (idVariable, ",".join(cols))
+            f'The variable "{idVariable}" not found in the DBF/GDF. '
+            f"The the following variables are present: {','.join(cols)}."
         )
-        raise KeyError(msg)
+        raise KeyError(msg) from None
 
 
 def get_points_array(iterable):
     """
     Gets a data array of x and y coordinates from a given iterable
+
     Parameters
     ----------
     iterable      : iterable
@@ -1070,7 +1044,6 @@ def get_points_array(iterable):
     -----
     If the given shape file includes polygons,
     this function returns x and y coordinates of the polygons' centroids
-
     """
     first_choice, backup = tee(iterable)
     try:
@@ -1086,7 +1059,7 @@ def get_points_array(iterable):
         else:
             data = np.vstack([np.array(shape.centroid) for shape in first_choice])
     except AttributeError:
-        data = np.vstack([shape for shape in backup])
+        data = np.vstack(list(backup))
     return data
 
 
@@ -1116,23 +1089,26 @@ def get_points_array_from_shapefile(shapefile):
 
     >>> import libpysal
     >>> from libpysal.weights.util import get_points_array_from_shapefile
-    >>> xy = get_points_array_from_shapefile(libpysal.examples.get_path('juvenile.shp'))
+    >>> xy = get_points_array_from_shapefile(
+    ...     libpysal.examples.get_path('juvenile.shp')
+    ... )
     >>> xy[:3]
     array([[94., 93.],
            [80., 95.],
            [79., 90.]])
 
-
     Polygon shapefile
 
-    >>> xy = get_points_array_from_shapefile(libpysal.examples.get_path('columbus.shp'))
+    >>> xy = get_points_array_from_shapefile(
+    ...     libpysal.examples.get_path('columbus.shp')
+    ... )
     >>> xy[:3]
     array([[ 8.82721847, 14.36907602],
            [ 8.33265837, 14.03162401],
            [ 9.01226541, 13.81971908]])
     """
 
-    f = psopen(shapefile)
+    f = FileIO(shapefile)
     data = get_points_array(f)
     return data
 
@@ -1143,7 +1119,6 @@ def min_threshold_distance(data, p=2):
 
     Parameters
     ----------
-
     data    : array
               (n,k) or KDTree where KDtree.data is array (n,k)
               n observations on k attributes
@@ -1168,7 +1143,6 @@ def min_threshold_distance(data, p=2):
     >>> data = np.hstack([x, y])
     >>> min_threshold_distance(data)
     1.0
-
     """
     if issubclass(type(data), scipy.spatial.KDTree):
         kd = data
@@ -1186,7 +1160,6 @@ def lat2SW(nrows=3, ncols=5, criterion="rook", row_st=False):
 
     Parameters
     ----------
-
     nrows   : int
               number of rows
     ncols   : int
@@ -1199,19 +1172,17 @@ def lat2SW(nrows=3, ncols=5, criterion="rook", row_st=False):
 
     Returns
     -------
-
     w : scipy.sparse.dia_matrix
         instance of a scipy sparse matrix
 
     Notes
     -----
-
-    Observations are row ordered: first k observations are in row 0, next k in row 1, and so on.
-    This method directly creates the W matrix using the strucuture of the contiguity type.
+    Observations are row ordered: first k observations are in row 0,
+    next k in row 1, and so on. This method directly creates the W
+    matrix using the strucuture of the contiguity type.
 
     Examples
     --------
-
     >>> from libpysal.weights import lat2SW
     >>> w9 = lat2SW(3,3)
     >>> w9[0,1] == 1
@@ -1261,17 +1232,15 @@ def lat2SW(nrows=3, ncols=5, criterion="rook", row_st=False):
 
 
 def write_gal(file, k=10):
-    f = open(file, "w")
-    n = k * k
-    f.write("0 %d" % n)
-    for i in range(n):
-        row = i / k
-        col = i % k
-        neighs = [i - i, i + 1, i - k, i + k]
-        neighs = [j for j in neighs if j >= 0 and j < n]
-        f.write("\n%d %d\n" % (i, len(neighs)))
-        f.write(" ".join(map(str, neighs)))
-    f.close()
+    with open(file, "w") as f:
+        n = k * k
+        f.write("0 %d" % n)
+        for i in range(n):
+            neighs = [i - i, i + 1, i - k, i + k]
+            neighs = [j for j in neighs if j >= 0 and j < n]
+            f.write("\n%d %d\n" % (i, len(neighs)))
+            f.write(" ".join(map(str, neighs)))
+        f.close()
 
 
 def neighbor_equality(w1, w2):
@@ -1280,23 +1249,19 @@ def neighbor_equality(w1, w2):
 
     Parameters
     ----------
-
     w1 : W
         instance of spatial weights class W
-
     w2 : W
         instance of spatial weights class W
 
     Returns
     -------
-    Boolean
-
+    bool
 
     Notes
     -----
     Only set membership is evaluated, no check of the weight values is carried out.
 
-
     Examples
     --------
     >>> from libpysal.weights.util import neighbor_equality
@@ -1321,7 +1286,6 @@ def neighbor_equality(w1, w2):
     >>> w5 = W(n5)
     >>> neighbor_equality(w1, w5)
     True
-
     """
     n1 = w1.neighbors
     n2 = w2.neighbors
@@ -1329,10 +1293,7 @@ def neighbor_equality(w1, w2):
     ids_2 = set(n2.keys())
     if ids_1 != ids_2:
         return False
-    for i in ids_1:
-        if set(w1.neighbors[i]) != set(w2.neighbors[i]):
-            return False
-    return True
+    return all(set(w1.neighbors[i]) == set(w2.neighbors[i]) for i in ids_1)
 
 
 def isKDTree(obj):
@@ -1340,7 +1301,7 @@ def isKDTree(obj):
     This is a utility function to determine whether or not an object is a
     KDTree, since KDTree and cKDTree have no common parent type
     """
-    return any([issubclass(type(obj), KDTYPE) for KDTYPE in KDTREE_TYPES])
+    return any([issubclass(type(obj), KDTYPE) for KDTYPE in KDTREE_TYPES])  # noqa: C419
 
 
 def attach_islands(w, w_knn1, **kwargs):
@@ -1349,7 +1310,6 @@ def attach_islands(w, w_knn1, **kwargs):
 
     Parameters
     ----------
-
     w            : libpysal.weights.W
                    pysal spatial weight object (unstandardized).
     w_knn1       : libpysal.weights.W
@@ -1357,7 +1317,6 @@ def attach_islands(w, w_knn1, **kwargs):
     **kwargs     : keyword arguments
                    optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
                  : libpysal.weights.W
@@ -1376,7 +1335,6 @@ def attach_islands(w, w_knn1, **kwargs):
     []
     >>> w_attach[w.islands[0]]
     {166: 1.0}
-
     """
 
     neighbors, weights = copy.deepcopy(w.neighbors), copy.deepcopy(w.weights)
@@ -1386,7 +1344,7 @@ def attach_islands(w, w_knn1, **kwargs):
     else:
         for island in w.islands:
             nb = w_knn1.neighbors[island][0]
-            if type(island) is float:
+            if isinstance(island, float):
                 nb = float(nb)
             neighbors[island] = [nb]
             weights[island] = [1.0]
@@ -1399,41 +1357,35 @@ def nonplanar_neighbors(w, geodataframe, tolerance=0.001, **kwargs):
     """
     Detect neighbors for non-planar polygon collections
 
-
     Parameters
     ----------
-
     w:   pysal W
          A spatial weights object with reported islands
-
-
     geodataframe: GeoDataframe
                   The polygon dataframe from which w was constructed.
-
     tolerance: float
-               The percentage of the minimum horizontal or vertical extent (minextent) of
-               the dataframe to use in defining  a buffering distance to allow for fuzzy
-               contiguity detection. The buffering distance is equal to tolerance*minextent.
+               The percentage of the minimum horizontal or vertical extent (minextent)
+               of the dataframe to use in defining  a buffering distance to allow for
+               fuzzy contiguity detection. The buffering distance is equal to
+               tolerance*minextent.
     **kwargs:  keyword arguments
                optional arguments for :class:`pysal.weights.W`
 
-
     Attributes
     ----------
-
     non_planar_joins : dictionary
-               Stores the new joins detected. Key is the id of the focal unit, value is a list of neighbor ids.
+               Stores the new joins detected. Key is the id of the focal unit,
+               value is a list of neighbor ids.
 
     Returns
     -------
-
     w: pysal W
        Spatial weights object that encodes fuzzy neighbors.
-       This will have an attribute `non_planar_joins` to indicate what new joins were detected.
+       This will have an attribute `non_planar_joins` to indicate
+       what new joins were detected.
 
     Notes
     -----
-
     This relaxes the notion of contiguity neighbors for the case of shapefiles
     that violate the condition of planar enforcement. It handles three types
     of conditions present in such files that would result in islands when using
@@ -1449,7 +1401,6 @@ def nonplanar_neighbors(w, geodataframe, tolerance=0.001, **kwargs):
 
     Examples
     --------
-
     >>> import geopandas as gpd
     >>> import libpysal
     >>> df = gpd.read_file(libpysal.examples.get_path('map_RS_BR.shp'))
@@ -1470,16 +1421,15 @@ def nonplanar_neighbors(w, geodataframe, tolerance=0.001, **kwargs):
 
     References
     ----------
-
-    Planar Enforcement: http://ibis.geog.ubc.ca/courses/klink/gis.notes/ncgia/u12.html#SEC12.6
-
-
-    """
+    Planar Enforcement:
+    http://ibis.geog.ubc.ca/courses/klink/gis.notes/ncgia/u12.html#SEC12.6
+    """  # noqa: E501
 
     gdf = geodataframe
-    assert (
-        gdf.sindex
-    ), "GeoDataFrame must have a spatial index. Please make sure you have `libspatialindex` installed"
+    assert gdf.sindex, (
+        "GeoDataFrame must have a spatial index. "
+        "Please make sure you have `libspatialindex` installed"
+    )
     islands = w.islands
     joins = copy.deepcopy(w.neighbors)
     candidates = gdf.geometry
@@ -1542,39 +1492,34 @@ def fuzzy_contiguity(
 
     Parameters
     ----------
-
     gdf:   GeoDataFrame
-
     tolerance: float
-               The percentage of the length of the minimum side of the bounding rectangle for the GeoDataFrame to use in determining the buffering distance.
-
+               The percentage of the length of the minimum side of the bounding
+               rectangle for the GeoDataFrame to use in determining the buffering
+               distance.
     buffering: boolean
-               If False (default) joins will only be detected for features that intersect (touch, contain, within).
-               If True then features will be buffered and intersections will be based on buffered features.
-
+               If False (default) joins will only be detected for features that
+               intersect (touch, contain, within). If True then features will be
+               buffered and intersections will be based on buffered features.
     drop: boolean
-          If True (default), the buffered features are removed from the GeoDataFrame. If False, buffered features are added to the GeoDataFrame.
-
+          If True (default), the buffered features are removed from the GeoDataFrame.
+          If False, buffered features are added to the GeoDataFrame.
     buffer : float
              Specify exact buffering distance. Ignores `tolerance`.
-
     predicate : {'intersects', 'within', 'contains', 'overlaps', 'crosses', 'touches'}
-                The predicate to use for determination of neighbors. Default is 'intersects'. If None is passed, neighbours are determined based on
+                The predicate to use for determination of neighbors. Default is
+                'intersects'. If None is passed, neighbours are determined based on
                 the intersection of bounding boxes.
-
     **kwargs: keyword arguments
               optional arguments for :class:`pysal.weights.W`
 
-
     Returns
     -------
-
     w:  PySAL W
         Spatial weights based on fuzzy contiguity. Weights are binary.
 
     Examples
     --------
-
     >>> import libpysal
     >>> from libpysal.weights import fuzzy_contiguity
     >>> import geopandas as gpd
@@ -1617,7 +1562,6 @@ def fuzzy_contiguity(
 
     Notes
     -----
-
     This relaxes the notion of contiguity neighbors for the case of feature
     collections that violate the condition of planar enforcement. It handles
     three types of conditions present in such collections that would result in
@@ -1629,17 +1573,15 @@ def fuzzy_contiguity(
     final case arises when one polygon is "inside" a second polygon but is not
     encoded to represent a hole in the containing polygon.
 
-    Detection of the second case will require setting buffering=True and exploring different values for tolerance.
+    Detection of the second case will require setting buffering=True
+    and exploring different values for tolerance.
 
     The buffering check assumes the geometry coordinates are projected.
 
-
     References
     ----------
-
-    Planar Enforcement: http://ibis.geog.ubc.ca/courses/klink/gis.notes/ncgia/u12.html#SEC12.6
-
-
+    Planar Enforcement:
+    http://ibis.geog.ubc.ca/courses/klink/gis.notes/ncgia/u12.html#SEC12.6
     """
     if buffering:
         if not buffer:
@@ -1677,8 +1619,6 @@ def fuzzy_contiguity(
 
 
 if __name__ == "__main__":
-    from libpysal.weights import lat2W
-
     assert (lat2W(5, 5).sparse.todense() == lat2SW(5, 5).todense()).all()
     assert (lat2W(5, 3).sparse.todense() == lat2SW(5, 3).todense()).all()
     assert (
